pub enum Threshold {
    AbsolutePercentage {
        percentage: PercentageThreshold,
    },
    ThresholdQuorum {
        threshold: PercentageThreshold,
        quorum: PercentageThreshold,
    },
    AbsoluteCount {
        threshold: Uint128,
    },
}
The ways a proposal may reach its passing / failing threshold.

Variants



AbsolutePercentage

Fields

Declares a percentage of the total weight that must cast Yes votes in order for a proposal to pass. See ThresholdResponse::AbsolutePercentage in the cw3 spec for details.



ThresholdQuorum

Declares a quorum of the total votes that must participate in the election in order for the vote to be considered at all. See ThresholdResponse::ThresholdQuorum in the cw3 spec for details.



AbsoluteCount

Fields

threshold: Uint128

An absolute number of votes needed for something to cross the threshold. Useful for multisig style voting.

Implementations

source

impl Threshold

source

pub fn validate(&self) -> Result<(), ThresholdError>

returns error if this is an unreachable value, given a total weight of all members in the group